@@ -18,7 +18,7 @@ module Gherkin
       @ands.empty?
     end
 
-    def eval(tags)
+    def evaluate(tags)
       return true if @ands.flatten.empty?
       vars = Hash[*tags.map{|tag| [tag.name, true]}.flatten]
       !!Kernel.eval(ruby_expression)
@@ -39,7 +39,7 @@ module Gherkin
         if limit
           tag_without_negation = negated ? tag_with_negation[1..-1] : tag_with_negation
           if @limits[tag_without_negation] && @limits[tag_without_negation] != limit.to_i
-            raise "Inconsistent tag limits for #{tag_without_negation}: #{@limits[tag_without_negation]} and #{limit.to_i}" 
+            raise "Inconsistent tag limits for #{tag_without_negation}: #{@limits[tag_without_negation]} and #{limit.to_i}"
           end
           @limits[tag_without_negation] = limit.to_i
         end
