@@ -53,7 +53,7 @@ module Gherkin
           [:step, "当", "我按相加按钮", 7],
           [:step, "那么", "我应该在屏幕上看到的结果是13", 8],
           [:eof]
-        ] 
+        ]
       end
 
       it "should parse languages with spaces after some keywords but not others" do
@@ -162,7 +162,7 @@ module Gherkin
         end
 
         it "should report keyword regexp" do
-          Gherkin::I18n.keyword_regexp(:step).should =~ /\|Quando \|Quand \|Quan \|Pryd \|Pokud \|/
+          Gherkin::I18n.keyword_regexp(:step).should =~ /\|Quando \|Quand \|Quan \|Pryd \|/
         end
 
         it "should print available languages" do
@@ -175,18 +175,23 @@ module Gherkin
       | cy-GB     | Welsh               | Cymraeg           |
       | da        | Danish              | dansk             |
       | de        | German              | Deutsch           |
+      | el        | Greek               | Ελληνικά          |
       | en        | English             | English           |
       | en-Scouse | Scouse              | Scouse            |
       | en-au     | Australian          | Australian        |
       | en-lol    | LOLCAT              | LOLCAT            |
+      | en-old    | Old English         | Englisc           |
       | en-pirate | Pirate              | Pirate            |
       | en-tx     | Texan               | Texan             |
       | eo        | Esperanto           | Esperanto         |
       | es        | Spanish             | español           |
       | et        | Estonian            | eesti keel        |
+      | fa        | Persian             | فارسی             |
       | fi        | Finnish             | suomi             |
       | fr        | French              | français          |
+      | gl        | Galician            | galego            |
       | he        | Hebrew              | עברית             |
+      | hi        | Hindi               | हिंदी             |
       | hr        | Croatian            | hrvatski          |
       | hu        | Hungarian           | magyar            |
       | id        | Indonesian          | Bahasa Indonesia  |
@@ -199,6 +204,7 @@ module Gherkin
       | lv        | Latvian             | latviešu          |
       | nl        | Dutch               | Nederlands        |
       | no        | Norwegian           | norsk             |
+      | pa        | Panjabi             | ਪੰਜਾਬੀ            |
       | pl        | Polish              | polski            |
       | pt        | Portuguese          | português         |
       | ro        | Romanian            | română            |
@@ -207,7 +213,10 @@ module Gherkin
       | sr-Cyrl   | Serbian             | Српски            |
       | sr-Latn   | Serbian (Latin)     | Srpski (Latinica) |
       | sv        | Swedish             | Svenska           |
+      | th        | Thai                | ไทย               |
+      | tl        | Telugu              | తెలుగు            |
       | tr        | Turkish             | Türkçe            |
+      | tt        | Tatar               | Татарча           |
       | uk        | Ukrainian           | Українська        |
       | uz        | Uzbek               | Узбекча           |
       | vi        | Vietnamese          | Tiếng Việt        |
@@ -235,6 +244,11 @@ module Gherkin
       | but (code)       | "Mais"                                                                                                                                                |
 }
         end
+
+        it "should not list keywords that start with a number" do
+          Gherkin::I18n.get('en-old').code_keywords.should include("Ðaðe")
+          Gherkin::I18n.get('en-old').code_keywords.should_not include("7")
+        end
       end
     end
   end
