@@ -286,7 +286,15 @@ f'real
           scan("Given I have a string\n\"\"\"\nhello\nworld\n\"\"\"")
           @listener.to_sexp.should == [
             [:step, "Given ", "I have a string", 1],
-            [:doc_string, "hello\nworld", 2],
+            [:doc_string, '', "hello\nworld", 2],
+            [:eof]
+          ]
+        end
+
+        it "should parse steps with an empty name" do
+          scan("Given ")
+          @listener.to_sexp.should == [
+            [:step, "Given ", "", 1],
             [:eof]
           ]
         end
@@ -497,7 +505,7 @@ f'real
             [:step, "Then ", "I am happy", 37],
             [:scenario, "Scenario", "Hammerzeit", "", 39],
             [:step, "Given ", "All work and no play", 40],
-            [:doc_string, "Makes Homer something something\nAnd something else", 41 ],
+            [:doc_string, '', "Makes Homer something something\nAnd something else", 41 ],
             [:step, "Then ", "crazy", 45],
             [:eof]
           ]
@@ -540,7 +548,7 @@ f'real
             [:step, "Then ", "I am happy", 37],
             [:scenario, "Scenario", "Hammerzeit", "", 39],
             [:step, "Given ", "All work and no play", 40],
-            [:doc_string, "Makes Homer something something\r\nAnd something else", 41],
+            [:doc_string, '', "Makes Homer something something\r\nAnd something else", 41],
             [:step, "Then ", "crazy", 45],
             [:eof]
           ]
