@@ -22,20 +22,32 @@ class RagelTask
   def define_tasks
     deps = [lang_ragel, common_ragel]
     deps.unshift(UGLIFYJS) if(@lang == 'js')
+    sed = RbConfig::CONFIG['host_os'] =~ /linux/i ? "sed -i" : "sed -i ''"
 
+    min_target = target.gsub(/\.js$/, '.min.js')
     file target => deps do
       mkdir_p(File.dirname(target)) unless File.directory?(File.dirname(target))
-      sh "ragel #{flags} #{lang_ragel} -o #{target}"
+      ragel = @lang == 'js' ? 'js/ragel-osx' : 'ragel'
+      sh "#{ragel} #{flags} #{lang_ragel} -o #{target}"
+      # Remove absolute paths from ragel-generated sources
+      sh %{#{sed} "s|#{Dir.pwd}/tasks/../||" #{target}}
       if(@lang == 'js')
         # Ragel chokes if we put the escaped triple quotes in .rl, so we'll do the replace with sed after the fact. Lots of backslashes!!
-        sed = Config::CONFIG['host_os'] =~ /linux/i ? "sed -i" : "sed -i ''"
         sh %{#{sed} 's/ESCAPED_TRIPLE_QUOTE/\\\\\\\\\\\\"\\\\\\\\\\\\"\\\\\\\\\\\\"/' #{target}}
+        sh %{#{sed} 's/const/var/' #{target}}
         
         # Minify
-        sh %{node #{UGLIFYJS} #{target} > #{target.gsub(/\.js$/, '.min.js')}}
+        sh %{node #{UGLIFYJS} #{target} > #{min_target}}
       end
     end
 
+    if(@lang != 'java')
+      CLEAN.include(target)
+    end
+    if(@lang == 'js')
+      CLEAN.include(min_target)
+    end
+
     file UGLIFYJS do
       unless File.exist?(UGLIFYJS)
         Dir.chdir('js') do
@@ -47,17 +59,21 @@ class RagelTask
     file lang_ragel => lang_erb do
       write(ERB.new(IO.read(lang_erb)).result(binding), lang_ragel)
     end
+    
+    CLEAN.include(lang_ragel)
 
     file common_ragel => common_erb  do
       write(ERB.new(IO.read(common_erb)).result(binding), common_ragel)
     end
+    
+    CLEAN.include(common_ragel)
   end
 
   def target
     {
       'c'    => "ext/gherkin_lexer_#{@i18n.underscored_iso_code}/gherkin_lexer_#{@i18n.underscored_iso_code}.c",
-      'java' => "java/src/main/java/gherkin/lexer/i18n/#{@i18n.underscored_iso_code.upcase}.java",
-      'rb'   => "lib/gherkin/rb_lexer/#{@i18n.underscored_iso_code}.rb",
+      'java' => "java/src/main/java/gherkin/lexer/#{@i18n.underscored_iso_code.capitalize}.java",
+      'rb'   => "lib/gherkin/lexer/#{@i18n.underscored_iso_code}.rb",
       'js'   => "js/lib/gherkin/lexer/#{@i18n.underscored_iso_code}.js"
     }[@lang]
   end
